export default {
    "index": 41,
    "lineNumber": 2,
    "column": 18,
    "message": "Cannot use 'await' as identifier inside an async function"
}
